Module: Meteor

Defined in:
lib/meteor.rb,
lib/meteor/parser.rb,
lib/meteor/element.rb,
lib/meteor/attribute.rb,
lib/meteor/core/kernel.rb,
lib/meteor/root_element.rb,
lib/meteor/attribute_map.rb,
lib/meteor/parser_factory.rb,
lib/meteor/element_factory.rb,
lib/meteor/ml/xml/parser_impl.rb,
lib/meteor/ml/html/parser_impl.rb,
lib/meteor/ml/html4/parser_impl.rb,
lib/meteor/ml/xhtml/parser_impl.rb,
lib/meteor/ml/xhtml4/parser_impl.rb,
lib/meteor/core/util/pattern_cache.rb,
lib/meteor/exception/no_such_element_exception.rb

Overview

Meteor - A lightweight (X)HTML(5) & XML parser

Copyright © 2008-present Yasumasa Ashida.

This program is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with this program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Author:

  • Yasumasa Ashida

Version:

  • 0.9.13

Defined Under Namespace

Modules: Core, Exception, Ml Classes: Attribute, AttributeMap, Element, ElementFactory, Parser, ParserFactory, RootElement

Constant Summary collapse

VERSION =
'0.9.13'
ZERO =

require ‘fileutils’

0
ONE =
1
TWO =
2
THREE =
3
FOUR =
4
FIVE =
5
SIX =
6
SEVEN =
7
HTML =
ZERO
XHTML =
ONE
HTML4 =
TWO
XHTML4 =
THREE
XML =
FOUR